@@ -3,7 +3,6 @@ __title__ = "connecty"
 __author__ = "Znunu"
 __version__ = "1.0.0"
 
-
-from .classes import *
-from .util import *
-from .args import parser
\ No newline at end of file
+from .gbl import GB
+from .rewrite import *
+from .args import parser
