@@ -3,6 +3,7 @@ from importlib import resources
 from configparser import ConfigParser
 import connecty, discord, string
 import colorama
+import types
 colorama.init()
 
 CBLUE = "\33[34m"
@@ -16,7 +17,7 @@ def wrap(cl):
     return fu
 
 print(wrap(CBLUE)("▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄"))
-print(wrap(CBLUE)("▉") + CVIOLET + CBOLD + " JOIN THE SUPPORT SERVER FOR HELP!! https://discord.gg/fcZBB2v " + wrap(CBLUE)("█"))
+print(wrap(CBLUE)("▉") + CBOLD + " JOIN THE SUPPORT SERVER FOR HELP!! https://discord.gg/fcZBB2v " + wrap(CBLUE)("█"))
 print(wrap(CBLUE)("█▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄█"))
 
 args = connecty.parser.parse_args()
@@ -26,19 +27,14 @@ config.read(args.config)
 bot = connecty.Bot()
 bot_config = dict(config["BOT"])
 del config["BOT"]
+connecty.GB.bot = bot
 
 @bot.configure
 async def init():
     for sec in config.sections():
         sec = config[sec]
-        connection = await bot.register(list(int(ids) for ids in sec["links"].split()), echo=sec.getboolean("echo"), repeat=sec.getboolean("repeat"))
-        @connection.on_message
-        async def on_msg(message: discord.Message):
-            new_content = message.content
-            if sec.getboolean("template"): new_content = string.Template(new_content).safe_substitute(sec)
-            payload = connecty.MessageLike.from_message(message)
-            payload.content = new_content
-            await connection.send(payload)
+        await bot.register(list(int(ids) for ids in sec["channels"].split()))
+
 
 def start(): bot.run(bot_config["token"])
-if __name__ == "__main__": start()
+if __name__ == "__main__": start()
\ No newline at end of file
